@@ -4,10 +4,10 @@ from .models import CustomerExtension, CustomerExtensionExtended, ValidatedTempl
 from .models import Departure
 from .models import Route
 from .models import Selection
-from typing import Iterator, Optional
+from typing import List, Iterator, Optional
 from datetime import datetime
 from .methods import calc_departures, calc_route_departure, recalculate_lead_time
-from typing import Protocol
+
 
 def MakeRoute(data: ValidatedTemplate) -> Iterator[Route]:
     data = data.copy()
@@ -74,7 +74,7 @@ def MakeSelection(data: ValidatedTemplate) -> Iterator[Selection]:
     data = data.copy()
     yield Selection.construct(
         EDES = data.EDEL,
-        PREX = ' 6',  # with preceeding space
+        PREX = ' 6',  # with preceding space
         OBV1 = data.EDEU,
         OBV2 = data.MODL,
         OBV3 = '',
@@ -97,19 +97,18 @@ def MakeCustomerExtension(data: ValidatedTemplate) -> Iterator[CustomerExtension
     if not data.ADOW\
     else calc_departures(data.DDOW, data.ARDY)
 
-    if data.PCUD or data.PCUH or data.PCUM:
-        for DDOW in list_of_departure_days:
-            RODN = calc_route_departure(DDOW, data.ARDY) if not data.RODN else data.RODN
+    for DDOW in list_of_departure_days:
+        RODN = calc_route_departure(DDOW, data.ARDY) if not data.RODN else data.RODN
 
-        yield CustomerExtension.construct(
-            FILE='DROUDI',
-            PK01=data.ROUT,
-            PK02=RODN,
-            A030=data.EDEU,
-            N096=data.PCUD if data.PCUD else None,
-            N196=data.PCUH if data.PCUH else None,
-            N296=data.PCUM if data.PCUM else None
-        )
+    yield CustomerExtension.construct(
+        FILE='DROUDI',
+        PK01=data.ROUT,
+        PK02=RODN,
+        A030=data.EDEU,
+        N096=data.PCUD if data.PCUD else None,
+        N196=data.PCUH if data.PCUH else None,
+        N296=data.PCUM if data.PCUM else None
+    )
 
     if data.CUSD:
         yield CustomerExtension.construct(
@@ -126,4 +125,47 @@ def MakeCustomerExtensionExtended(data: ValidatedTemplate) -> Iterator[CustomerE
                 FILE='DROUTE',
                 PK01=data.ROUT,
                 CHB1=data.CUSD
-            )
\ No newline at end of file
+            )
+        
+        
+def MakeTemplate(
+    route: Route,
+    departures: List[Departure],
+    selection: Selection,
+    cugex: Optional[CustomerExtension] = None,
+    cugexex: Optional[CustomerExtensionExtended] = None
+    ):
+
+    return ValidatedTemplate(
+        ROUT=route.ROUT,
+        EDEL=route.SDES,
+        EDEU=selection.EDES if selection else '',
+        TSID=route.TSID,
+        MODL=departures[0].WRMODL if departures else '',
+        RODN='',
+        DDOW=selection.DDOW,
+        FWNO=departures[0].WRFWNO if departures else '',
+        ARDY=min([d.WRARDY for d in departures if d.WRARDY]) if departures else 0,
+        ARDX=selection.LOLD,
+        TRCA=selection.TRCA,
+        LILD=departures[0].WRLILD,
+        LILH=departures[0].WRLILH,
+        LILM=departures[0].WRLILM,
+        SILD=departures[0].WRSILD,
+        SILH=departures[0].WRSILH,
+        SILM=departures[0].WRSILM,
+        FWLD=departures[0].WEFWLD,
+        FWLH=departures[0].WEFWLH,
+        FWLM=departures[0].WEFWLM,
+        PCUD=cugex.N096 if cugex else None,
+        PCUH=cugex.N196 if cugex else None,
+        PCUM=cugex.N296 if cugex else None,
+        DETH=departures[0].WRDETH,
+        DETM=departures[0].WRDETM,
+        ARHH=departures[0].WRARHH,
+        ARMM=departures[0].WRARMM,
+        RRSP=route.RESP,
+        DRSP=departures[0].WRRESP,
+        CUSD=cugexex.CHB1 if cugexex else 0,
+        ADOW=all([int(d.WWRODN) in [1, 2, 3, 4] for d in departures])
+    )
\ No newline at end of file
