@@ -1,5 +1,55 @@
-from typing import Optional, Generator
+from functools import wraps
+import re
+from typing import Any, Callable, Generator, Optional, TypeGuard
 
+
+
+def mark_as_obsolete(hint: Optional[str] = '') -> Callable:
+    def outer(func: Callable):
+        @wraps(func)
+        def inner(*args, **kwargs):
+            print(f'Obsolete: Fuction "{__name__}.{func.__name__}" is will be removed in future versions ({hint})')
+            return func(*args, **kwargs)
+        
+        return inner
+    
+    return outer
+    
+
+def to_str(value: int) -> str:
+    ''' Converts a given integer to the corresponding string value '''
+        
+    a = chr(((value // 10000) // 26) % 26 + 65)
+    b = chr((value // 10000) % 26 + 65)
+    c = str(value % 10000).zfill(4)
+    
+    return a + b + c
+
+
+def to_int(value: str) -> int:
+    ''' Converts a given string to the corresponding integer value '''
+    a = (ord(value[0]) - 65) * 260000
+    b = (ord(value[1]) - 65) * 10000
+    c = int(value[2:])
+
+    return a + b + c
+    
+
+def is_valid_str(value: Any) -> TypeGuard[str]:
+    ''' Checks if a given string is a valid sequence number '''
+    return True if re.match("^[A-Z]{2}[0-9]{4}$", str(value)) and isinstance(value, str) else False
+
+
+def is_valid_int(value: Any) -> TypeGuard[int]:
+    ''' Checks if a given integer is a valid sequence number '''
+    try:
+        return value >= 0 and value < 6760000
+
+    except TypeError:
+        return False
+
+
+@mark_as_obsolete('Use to_int and a range instead')
 def increment(sequenceNumber: Optional[str] = None) -> str:
     '''Taked a route sequence number and incriments by one.
     >>> increment(None)
@@ -16,7 +66,7 @@ def increment(sequenceNumber: Optional[str] = None) -> str:
 
     return _next(sequenceNumber)
 
-
+@mark_as_obsolete('Use to_int and a range instead')
 def generator(sequenceNumber: Optional[str] = None, n: Optional[int] = None) -> Generator:
     '''Returns a sequence generator. If n is not given it will loop infinitely'''
     if sequenceNumber:
@@ -24,7 +74,6 @@ def generator(sequenceNumber: Optional[str] = None, n: Optional[int] = None) ->
 
     return _generator(sequenceNumber, n)
 
-
 def _validate_seed(sequenceNumber: str) -> None:
     '''Validate the input of a seed'''
     if len(sequenceNumber) != 6:
@@ -34,7 +83,7 @@ def _validate_seed(sequenceNumber: str) -> None:
     elif not sequenceNumber[2:].isdigit():
         raise ValueError('The last four chars of the sequence number has to be numeric')
 
-
+@mark_as_obsolete(hint='Use is_int_valid or is_str_valid instead')
 def is_sequenceNumber_valid(sequenceNumber: str):
     ''' Returns True if seed is valid, else False. Can be used in a functional way
     to determine if a sequence number is valid or not, or to filter out route names that follows
@@ -67,7 +116,6 @@ def _generator(sequenceNumber: Optional[str] = None, n: Optional[int] = None) ->
             sequenceNumber = _next(sequenceNumber)
             yield sequenceNumber
         
-
 def _next(sequenceNumber: Optional[str] = None) -> str:
     '''Taked a route sequence number and incriments by one.'''
     if sequenceNumber:
@@ -82,7 +130,6 @@ def _next(sequenceNumber: Optional[str] = None) -> str:
     else:
         return 'AA0001'
 
-        
 def _incrementAlpha(alpha: str) -> str:
     '''Takes a upper char string and increments as it's a number sequence.
     
@@ -103,7 +150,6 @@ def _incrementAlpha(alpha: str) -> str:
 
     return ''.join(reversed(alphaArray))
 
-
 def _incrementDigit(alpha: str) -> str:
     ''' Takes a digit as string type and returns as equal length number as string.
         Number is reset to 1 when max number is reached.    
